package ui;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.Font;
import java.awt.Rectangle;
import java.awt.Color;
import javax.swing.*;
import java.awt.event.*;

import engine.*;

/**
 * <p>This is the first frame of ALTMMR program.</p>
 */
public class ALTMMRFrame extends JFrame implements ActionListener, SubGroupListener
{
    private static final boolean DEBUG = true;

    private JLabel lblTitle = new JLabel();
    private JLabel lblSubGroups = new JLabel();
    private JTextField txtSubGroups = new JTextField();
    private JLabel lblAlpha = new JLabel();
    private JRadioButton alpha1 = new JRadioButton();
    private JRadioButton alpha2 = new JRadioButton();
    private JButton btnOK = new JButton();
    private JButton btnExit = new JButton();
    private JButton btnHelp = new JButton();
    private JButton btnPrint = new JButton();
    private ButtonGroup group;

    private EngineInput engineInput = null;
    private EngineOutput engineOutput = null;
	private OutputFrame output = null; 

    public static void main(String[] args)
    {

        ALTMMRFrame frame = new ALTMMRFrame();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setTitle("ALTMMR");
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension frameSize = frame.getSize();
            if (frameSize.height > screenSize.height) {
                frameSize.height = screenSize.height;
            }
            if (frameSize.width > screenSize.width) {
                frameSize.width = screenSize.width;
            }
            frame.setLocation((screenSize.width - frameSize.width) / 2, (screenSize.height - frameSize.height) / 2);
            frame.addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                    System.exit(0);
                }
            });
            frame.setVisible(true);
    }

    public ALTMMRFrame()
    {
        this.getContentPane().setLayout(null);
        this.getContentPane().setBackground(Color.white);
        this.setSize(new Dimension(450, 300));

        lblTitle.setText("Welcome to ALTMMR");
        lblTitle.setBounds(new Rectangle(138, 10, 150, 30));
        lblTitle.setFont(new Font("Dialog", 1, 12));

        lblSubGroups.setText("Number of Sub-Groups in Your Sample");
        lblSubGroups.setBounds(new Rectangle(15, 60, 260, 25));
        lblSubGroups.setFont(new Font("Dialog", 1, 12));

        txtSubGroups.setBounds(new Rectangle(270, 60, 115, 30));

        lblAlpha.setText("Alpha Level for James\' Test");
        lblAlpha.setBounds(new Rectangle(15, 110, 190, 25));
        lblAlpha.setFont(new Font("Dialog", 1, 12));

        alpha1.setText("0.01");
        alpha1.setActionCommand("0.01");
        alpha1.setFont(new Font("Dialog", 1, 12));
        alpha1.setBounds(new Rectangle(220, 110, 90, 25));
        alpha1.setBackground(Color.white);


        alpha2.setText("0.05");
        alpha2.setActionCommand("0.05");
        alpha2.setFont(new Font("Dialog", 1, 12));
        alpha2.setBounds(new Rectangle(310, 110, 90, 25));
        alpha2.setBackground(Color.white);
        alpha2.setSelected(true);

        group = new ButtonGroup();
        group.add(alpha1);
        group.add(alpha2);

        btnOK.setText("OK");
        btnOK.setBounds(new Rectangle(50, 185, 90, 25));
        btnOK.setFont(new Font("Dialog", 1, 12));
        btnOK.setActionCommand("OK");
        btnOK.addActionListener(this);

        btnExit.setText("Exit");
        btnExit.setBounds(new Rectangle(150, 185, 90, 25));
        btnExit.setFont(new Font("Dialog", 1, 12));
        btnExit.setActionCommand("Exit");
        btnExit.addActionListener(this);

        btnHelp.setText("Help");
        btnHelp.setBounds(new Rectangle(250, 185, 90, 25));
        btnHelp.setFont(new Font("Dialog", 1, 12));
        btnHelp.setActionCommand("Help");
        btnHelp.addActionListener(this);
        
		btnPrint.setText("Print");
		btnPrint.setBounds(new Rectangle(350, 185, 90, 25));
		btnPrint.setFont(new Font("Dialog", 1, 12));
		btnPrint.setActionCommand("Print");
		btnPrint.addActionListener(this);

        this.getContentPane().add(lblTitle, null);
        this.getContentPane().add(lblSubGroups, null);
        this.getContentPane().add(txtSubGroups, null);
        this.getContentPane().add(lblAlpha, null);
        this.getContentPane().add(alpha1, null);
        this.getContentPane().add(alpha2, null);
        this.getContentPane().add(btnOK, null);
        this.getContentPane().add(btnExit, null);
        this.getContentPane().add(btnHelp, null);
    }

    public void actionPerformed(ActionEvent ae) 
    {
        if(ae.getActionCommand().equals("OK")) {

            try {
                double alpha = Double.parseDouble(group.getSelection().getActionCommand());
                int m_k = Integer.parseInt(txtSubGroups.getText());

                if((m_k == 0 || m_k <= -1 || m_k == 1)) {
                    JOptionPane.showMessageDialog(null,
                    "Subgroup size must be a positive number greater than one.",
                    "Alert",
                    JOptionPane.ERROR_MESSAGE);
                    txtSubGroups.setText("");
                    txtSubGroups.requestFocus();
                    return;
                }

                InputDataFrame inputDataFrame = new InputDataFrame(this);
                inputDataFrame.addSubGroupListener(this);


                // Initialize the input
                engineInput = new EngineInput(m_k);
                engineInput.setMAlpha(alpha);

                // Populate the dialog to collect subgroup data
                for(int i = 1; i <= m_k; i++) {
                    inputDataFrame.clearDialog();
                    inputDataFrame.setTitle("Input Data For Subgroup " + i);
                    inputDataFrame.lblTitle.setText("Input Data for Sub-Group " + i);
                    if(i == m_k) {
                        inputDataFrame.btnNext.setText("OK");
                    }
                    
					Dimension s = Toolkit.getDefaultToolkit().getScreenSize();
					Dimension f = inputDataFrame.getSize();
					if (f.height > s.height) {
						f.height = s.height;
					}
					if (f.width > s.width) {
						f.width = s.width;
					}
					inputDataFrame.setLocation((s.width - f.width) / 2 - 50, (s.height - f.height) / 2 - 50);
                    inputDataFrame.setVisible(true);
                }

                engineOutput = Engine.calc(engineInput);

                output = new OutputFrame(engineInput, engineOutput);
				Dimension s = Toolkit.getDefaultToolkit().getScreenSize();
				Dimension f = output.getSize();
				if (f.height > s.height) {
					f.height = s.height;
				}
				if (f.width > s.width) {
					f.width = s.width;
				}
				output.setLocation((s.width - f.width) / 2, (s.height - f.height) / 2);
				//  output.pack();
                output.setVisible(true);

            } catch(NumberFormatException nfe) {
                JOptionPane.showMessageDialog(null,
                        "Only numbers are allowed. Please verify the input values.",
                        "Alert",
                        JOptionPane.ERROR_MESSAGE);
                        txtSubGroups.setText("");
                        txtSubGroups.requestFocus();

            }

        } else if(ae.getActionCommand().equals("Exit")) {

            this.hide();
            this.dispose();

        } else if(ae.getActionCommand().equals("Help")) {

            String message = "This program computes statistics for your research sample.\n" +
                "The number of Subgroups refers to your categorical variable.\n" +
                "For example, if you are checking for gender bias, you have 2 sub-groups, male and female.\n" +
                "You will get a precise p-value for all statistics except \n" +
                "James's text-for this you will see the adjusted critical value.\n\n" +
                "For more detailed help, go to ALTMMR homepage.";

            JOptionPane.showMessageDialog(this, message, "ALRMMR Help", JOptionPane.INFORMATION_MESSAGE);
        } else if(ae.getActionCommand().equals("Print")) {
        	
			java.awt.Component c = (java.awt.Component) output;
			PrintUtil.printComponent(c);
        	
        }
    }

    public void handleSubGroupData(double sn, double ssx, double ssy, double srxy)
    {
        engineInput.addSubGroupData(sn, ssx, ssy, srxy);
    }
    public void originalInput(String sn, String ssx, String ssy, String srxy)
    {
        engineInput.addSubGroupData(sn, ssx, ssy, srxy);
    }
}
