package ui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.BadLocationException;
import javax.swing.text.DefaultStyledDocument;
import javax.swing.text.MutableAttributeSet;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;

import engine.*;

/**
 * @author Vara Allamaraju
 */
public class OutputFrame extends JFrame implements ActionListener {

	private JTextPane textPane;
	private StyledDocument doc;
	private MutableAttributeSet attr;

	private JScrollPane scrollableTextArea;

	private JButton btnExit;
	private JButton btnPrint;

	public OutputFrame(EngineInput in, EngineOutput out) {
		int offset = 0;

		this.getContentPane().setLayout(new BorderLayout());
		this.getContentPane().setBackground(Color.white);
		this.setSize(new Dimension(950, 600));

		textPane = new JTextPane();
		scrollableTextArea =
			new JScrollPane(
				textPane,
				JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,
				JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		try {

			attr = new SimpleAttributeSet();
			doc = new DefaultStyledDocument();
			textPane.setDocument(doc);
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 14);
			StyleConstants.setBold(attr, true);
			StyleConstants.setForeground(attr, new Color(27, 50, 150));
			StyleConstants.setLeftIndent(attr, 2.3F);
			StyleConstants.setAlignment(attr, StyleConstants.ALIGN_CENTER);
			String title = "ALTMMR Results\n";
			doc.insertString(offset, title, attr);
			offset = offset + title.length();
			
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			StyleConstants.setAlignment(attr, StyleConstants.ALIGN_LEFT);
			StyleConstants.setForeground(attr, Color.black);
			String s1 = "\nSub-Group\t\tSub-Group Size(n)\tPredictor Std.deviation (S ";
			doc.insertString(offset, s1, attr);
			offset = offset + s1.length();
			
			
			StyleConstants.setSubscript(attr, true);
			StyleConstants.setFontSize(attr, 12);
			doc.insertString(offset, "x", attr);
			offset = offset + 1;
			
			StyleConstants.setSubscript(attr, false);			
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			doc.insertString(offset, " )", attr);
			offset =  offset + 2;
			
			String s2 = "\tCriterion Std.deviation (S ";
			doc.insertString(offset, s2, attr);
			offset = offset + s2.length();
			
			StyleConstants.setSubscript(attr, true);
			StyleConstants.setFontSize(attr, 12);
			doc.insertString(offset, "y", attr);
			offset = offset + 1;
			
			StyleConstants.setSubscript(attr, false);			
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			doc.insertString(offset, " )", attr);
			offset =  offset + 2;
			
			String s3 = "\tCorrelation for X and Y(r ";
			doc.insertString(offset, s3, attr);
			offset = offset + s3.length();
			
			StyleConstants.setSubscript(attr, true);
			StyleConstants.setFontSize(attr, 11);
			doc.insertString(offset, "xy", attr);
			offset = offset + 2;
			
			
			StyleConstants.setSubscript(attr, false);			
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			doc.insertString(offset, " )", attr);
			offset =  offset + 2;
			
			int s = in.getSize();
			double m_narray[] = in.getMn();
			double m_sxarray[] = in.getMsx();
			double m_syarray[] = in.getMsy();
			double m_rxyarray[] = in.getMrxy();
			String data = null;
			for (int i = 0; i < s; i++) {
				data ="\n" + Integer.toString(i + 1) + "\t\t" + in.s_narray[i] + "\t\t\t"
				+ in.s_sxarray[i] + "\t\t\t" + in.s_syarray[i] + "\t\t\t" + in.s_rxyarray[i];
				doc.insertString(offset, data, attr);
				offset = offset + data.length();

			}
			
			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 14);
			StyleConstants.setBold(attr, true);
			StyleConstants.setForeground(attr, new Color(150, 50, 12));
			StyleConstants.setAlignment(attr, StyleConstants.ALIGN_CENTER);
			String str2 = "\n\nError Variance Results";
			doc.insertString(offset, str2, attr);

			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			StyleConstants.setForeground(attr, Color.black);
			StyleConstants.setAlignment(attr, StyleConstants.ALIGN_LEFT);
			
			String str3 = "\nDeShon & Alexander's rule of thumb for homogenity";
			offset = offset + str2.length();
			doc.insertString(offset, str3, attr);

			String str4 = out.getThumb();
			offset += str3.length();
			doc.insertString(offset, str4, attr);

			String str5 = "\nBartlett\'s Test  " + out.getBartlett();
			offset = offset + str4.length();
			doc.insertString(offset, str5, attr);

			//String str6 = "  " + out.getHomo() + "\n";
			//offset = offset + str5.length();
			//doc.insertString(offset, str6, attr);
			//txtThumb.append("\n" + out.getHomo2());

			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 14);
			StyleConstants.setBold(attr, true);
			StyleConstants.setForeground(attr, new Color(129, 50, 12));
			StyleConstants.setAlignment(attr, StyleConstants.ALIGN_CENTER);
			String str7 = "\n\nAlternative Differential Slopes Statistics";
			offset = offset + str5.length();
			doc.insertString(offset, str7, attr);

			StyleConstants.setFontFamily(attr, "Dialog");
			StyleConstants.setFontSize(attr, 12);
			StyleConstants.setBold(attr, true);
			//StyleConstants.setAlignment(attr, StyleConstants.ALIGN_LEFT);
			StyleConstants.setForeground(attr, Color.black);
			String str8 = "\nJames\'s Test" + out.getJames();
			offset = offset + str7.length();
			doc.insertString(offset, str8, attr);

			String str9 = "\nAlexander\'s Test   " + out.getAlex();
			offset = offset + str8.length();
			doc.insertString(offset, str9, attr);
			//txtJames.append("\n" + out.getMeaning());

		} catch (BadLocationException be) {
			be.printStackTrace();
		}
		btnExit = new JButton("Exit");
		btnExit.setFont(new Font("Dialog", 1, 12));
		btnExit.addActionListener(this);
		btnExit.setActionCommand("Exit");

		btnPrint = new JButton("Print");
		btnPrint.setFont(new Font("Dialog", 1, 12));
		btnPrint.addActionListener(this);
		btnPrint.setActionCommand("Print");

		JPanel btnPanel = new JPanel();
		btnPanel.setBackground(Color.white);
		btnPanel.setLayout(new GridLayout(2, 2, 15, 15));
		btnPanel.add(Box.createRigidArea(new Dimension(3, 0)));
		btnPanel.add(btnPrint);
		btnPanel.add(btnExit);
		btnPanel.add(Box.createRigidArea(new Dimension(3, 0)));
		btnPanel.add(Box.createRigidArea(new Dimension(3, 0)));
		btnPanel.add(Box.createHorizontalGlue());
		btnPanel.add(Box.createHorizontalGlue());

		this.getContentPane().add(scrollableTextArea, BorderLayout.CENTER);
		this.getContentPane().add(btnPanel, BorderLayout.SOUTH);
	}

	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals("Exit")) {

			this.hide();
			this.dispose();

		} else if (e.getActionCommand().equals("Print")) {

			java.awt.Component c = (java.awt.Component) textPane;
			PrintUtil.printComponent(c);
		}
	}
}
